@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -36,6 +36,7 @@ use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
 use AsposeCellsCloud::Object::Area;
+use AsposeCellsCloud::Object::DisplayUnitLabel;
 use AsposeCellsCloud::Object::Line;
 use AsposeCellsCloud::Object::Link;
 use AsposeCellsCloud::Object::LinkElement;
@@ -123,7 +124,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Encapsulates the object that represents an axis of chart.',
                                   class => 'Axis',
                                   required => [], # TODO
 }                                 );
@@ -133,238 +134,238 @@ __PACKAGE__->method_documentation({
      'area' => {
      	datatype => 'Area',
      	base_name => 'Area',
-     	description => '',
+     	description => 'Gets the .',
      	format => '',
      	read_only => '',
      		},
      'axis_between_categories' => {
      	datatype => 'boolean',
      	base_name => 'AxisBetweenCategories',
-     	description => '',
+     	description => 'Represents if the value axis crosses the category axis between categories.',
      	format => '',
      	read_only => '',
      		},
      'axis_line' => {
      	datatype => 'Line',
      	base_name => 'AxisLine',
-     	description => '',
+     	description => 'Gets the appearance of an Axis.',
      	format => '',
      	read_only => '',
      		},
      'base_unit_scale' => {
      	datatype => 'string',
      	base_name => 'BaseUnitScale',
-     	description => '',
+     	description => 'Represents the base unit scale for the category axis.',
      	format => '',
      	read_only => '',
      		},
      'category_type' => {
      	datatype => 'string',
      	base_name => 'CategoryType',
-     	description => '',
+     	description => 'Represents the category axis type.',
      	format => '',
      	read_only => '',
      		},
      'cross_at' => {
      	datatype => 'double',
      	base_name => 'CrossAt',
-     	description => '',
+     	description => 'Represents the point on the value axis where the category axis crosses it.',
      	format => '',
      	read_only => '',
      		},
      'cross_type' => {
      	datatype => 'string',
      	base_name => 'CrossType',
-     	description => '',
+     	description => 'Represents the  on the specified axis where the other axis crosses.',
      	format => '',
      	read_only => '',
      		},
      'display_unit' => {
      	datatype => 'string',
      	base_name => 'DisplayUnit',
-     	description => '',
+     	description => 'Represents the unit label for the specified axis.',
      	format => '',
      	read_only => '',
      		},
      'display_unit_label' => {
-     	datatype => 'LinkElement',
+     	datatype => 'DisplayUnitLabel',
      	base_name => 'DisplayUnitLabel',
-     	description => '',
+     	description => 'Represents a unit label on an axis in the specified chart.                         Unit labels are useful for charting large values— for example, in the millions or billions.',
      	format => '',
      	read_only => '',
      		},
      'has_multi_level_labels' => {
      	datatype => 'boolean',
      	base_name => 'HasMultiLevelLabels',
-     	description => '',
+     	description => 'Indicates whether the labels shall be shown as multi level.',
      	format => '',
      	read_only => '',
      		},
      'is_automatic_major_unit' => {
      	datatype => 'boolean',
      	base_name => 'IsAutomaticMajorUnit',
-     	description => '',
+     	description => 'Indicates whether the major unit of the axis is automatically assigned.',
      	format => '',
      	read_only => '',
      		},
      'is_automatic_max_value' => {
      	datatype => 'boolean',
      	base_name => 'IsAutomaticMaxValue',
-     	description => '',
+     	description => 'Indicates whether the max value is automatically assigned.',
      	format => '',
      	read_only => '',
      		},
      'is_automatic_minor_unit' => {
      	datatype => 'boolean',
      	base_name => 'IsAutomaticMinorUnit',
-     	description => '',
+     	description => 'Indicates whether the minor unit of the axis is automatically assigned.',
      	format => '',
      	read_only => '',
      		},
      'is_automatic_min_value' => {
      	datatype => 'boolean',
      	base_name => 'IsAutomaticMinValue',
-     	description => '',
+     	description => 'Indicates whether the min value is automatically assigned.',
      	format => '',
      	read_only => '',
      		},
      'is_display_unit_label_shown' => {
      	datatype => 'boolean',
      	base_name => 'IsDisplayUnitLabelShown',
-     	description => '',
+     	description => 'Represents if the display unit label is shown on the specified axis.',
      	format => '',
      	read_only => '',
      		},
      'is_logarithmic' => {
      	datatype => 'boolean',
      	base_name => 'IsLogarithmic',
-     	description => '',
+     	description => 'Represents if the value axis scale type is logarithmic or not.',
      	format => '',
      	read_only => '',
      		},
      'is_plot_order_reversed' => {
      	datatype => 'boolean',
      	base_name => 'IsPlotOrderReversed',
-     	description => '',
+     	description => 'Represents if Microsoft Excel plots data points from last to first.',
      	format => '',
      	read_only => '',
      		},
      'is_visible' => {
      	datatype => 'boolean',
      	base_name => 'IsVisible',
-     	description => '',
+     	description => 'Represents if the axis is visible.',
      	format => '',
      	read_only => '',
      		},
      'log_base' => {
      	datatype => 'double',
      	base_name => 'LogBase',
-     	description => '',
+     	description => 'Represents the logarithmic base. Default value is 10.Only applies for Excel2007.',
      	format => '',
      	read_only => '',
      		},
      'major_grid_lines' => {
      	datatype => 'Line',
      	base_name => 'MajorGridLines',
-     	description => '',
+     	description => 'Represents major gridlines on a chart axis.',
      	format => '',
      	read_only => '',
      		},
      'major_tick_mark' => {
      	datatype => 'string',
      	base_name => 'MajorTickMark',
-     	description => '',
+     	description => 'Represents the type of major tick mark for the specified axis.',
      	format => '',
      	read_only => '',
      		},
      'major_unit' => {
      	datatype => 'double',
      	base_name => 'MajorUnit',
-     	description => '',
+     	description => 'Represents the major units for the axis.',
      	format => '',
      	read_only => '',
      		},
      'major_unit_scale' => {
      	datatype => 'string',
      	base_name => 'MajorUnitScale',
-     	description => '',
+     	description => 'Represents the major unit scale for the category axis.',
      	format => '',
      	read_only => '',
      		},
      'max_value' => {
      	datatype => 'double',
      	base_name => 'MaxValue',
-     	description => '',
+     	description => 'Represents the maximum value on the value axis.',
      	format => '',
      	read_only => '',
      		},
      'minor_grid_lines' => {
      	datatype => 'Line',
      	base_name => 'MinorGridLines',
-     	description => '',
+     	description => 'Represents minor gridlines on a chart axis.',
      	format => '',
      	read_only => '',
      		},
      'minor_tick_mark' => {
      	datatype => 'string',
      	base_name => 'MinorTickMark',
-     	description => '',
+     	description => 'Represents the type of minor tick mark for the specified axis.',
      	format => '',
      	read_only => '',
      		},
      'minor_unit' => {
      	datatype => 'double',
      	base_name => 'MinorUnit',
-     	description => '',
+     	description => 'Represents the minor units for the axis.',
      	format => '',
      	read_only => '',
      		},
      'minor_unit_scale' => {
      	datatype => 'string',
      	base_name => 'MinorUnitScale',
-     	description => '',
+     	description => 'Represents the major unit scale for the category axis.',
      	format => '',
      	read_only => '',
      		},
      'min_value' => {
      	datatype => 'double',
      	base_name => 'MinValue',
-     	description => '',
+     	description => 'Represents the minimum value on the value axis.',
      	format => '',
      	read_only => '',
      		},
      'tick_label_position' => {
      	datatype => 'string',
      	base_name => 'TickLabelPosition',
-     	description => '',
+     	description => 'Represents the position of tick-mark labels on the specified axis.',
      	format => '',
      	read_only => '',
      		},
      'tick_labels' => {
      	datatype => 'TickLabels',
      	base_name => 'TickLabels',
-     	description => '',
+     	description => 'Returns a  object that represents the tick-mark labels for the specified axis.',
      	format => '',
      	read_only => '',
      		},
      'tick_label_spacing' => {
      	datatype => 'int',
      	base_name => 'TickLabelSpacing',
-     	description => '',
+     	description => 'Represents the number of categories or series between tick-mark labels. Applies only to category and series axes.',
      	format => '',
      	read_only => '',
      		},
      'tick_mark_spacing' => {
      	datatype => 'int',
      	base_name => 'TickMarkSpacing',
-     	description => '',
+     	description => 'Returns or sets the number of categories or series between tick marks. Applies only to category and series axes.',
      	format => '',
      	read_only => '',
      		},
      'title' => {
      	datatype => 'Title',
      	base_name => 'Title',
-     	description => '',
+     	description => 'Gets the axis` title.',
      	format => '',
      	read_only => '',
      		},
@@ -386,7 +387,7 @@ __PACKAGE__->swagger_types( {
     'cross_at' => 'double',
     'cross_type' => 'string',
     'display_unit' => 'string',
-    'display_unit_label' => 'LinkElement',
+    'display_unit_label' => 'DisplayUnitLabel',
     'has_multi_level_labels' => 'boolean',
     'is_automatic_major_unit' => 'boolean',
     'is_automatic_max_value' => 'boolean',
