@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -119,7 +119,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => '           Represents all types of color.           ',
                                   class => 'CellsColor',
                                   required => [], # TODO
 }                                 );
@@ -129,21 +129,21 @@ __PACKAGE__->method_documentation({
      'color' => {
      	datatype => 'Color',
      	base_name => 'Color',
-     	description => 'Gets and sets the RGB color.',
+     	description => 'Gets and sets the RGB color. ',
      	format => '',
      	read_only => '',
      		},
      'color_index' => {
      	datatype => 'int',
      	base_name => 'ColorIndex',
-     	description => 'Gets and sets the color index in the color palette. Only applies of indexed color.',
+     	description => 'Gets and sets the color index in the color palette. Only applies of indexed color. ',
      	format => '',
      	read_only => '',
      		},
      'is_shape_color' => {
      	datatype => 'boolean',
      	base_name => 'IsShapeColor',
-     	description => 'Gets and set the color which should apply to cell or shape.',
+     	description => 'Gets and set the color which should apply to cell or shape. ',
      	format => '',
      	read_only => '',
      		},
@@ -157,28 +157,28 @@ __PACKAGE__->method_documentation({
      'argb' => {
      	datatype => 'int',
      	base_name => 'Argb',
-     	description => 'Gets and sets the color from a 32-bit ARGB value.',
+     	description => 'Gets and sets the color from a 32-bit ARGB value. ',
      	format => '',
      	read_only => '',
      		},
      'theme_color' => {
      	datatype => 'ThemeColor',
      	base_name => 'ThemeColor',
-     	description => 'Gets the theme color. Only applies for theme color type.            ',
+     	description => 'Gets the theme color. Only applies for theme color type. ',
      	format => '',
      	read_only => '',
      		},
      'type' => {
      	datatype => 'string',
      	base_name => 'Type',
-     	description => 'The color type.',
+     	description => 'The color type. ',
      	format => '',
      	read_only => '',
      		},
      'transparency' => {
      	datatype => 'double',
      	base_name => 'Transparency',
-     	description => 'Gets and sets transparency as a value from 0.0 (opaque) through 1.0 (clear).',
+     	description => 'Gets and sets transparency as a value from 0.0 (opaque) through 1.0 (clear). ',
      	format => '',
      	read_only => '',
      		},    
