@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -35,6 +35,7 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
+use AsposeCellsCloud::Object::DataSource;
 use AsposeCellsCloud::Object::FileSource;
 use AsposeCellsCloud::Object::SaveOptions;
 use AsposeCellsCloud::Object::TaskParameter; 
@@ -120,45 +121,63 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents convert task parameter.',
                                   class => 'ConvertTaskParameter',
                                   required => [], # TODO
 }                                 );
 
 
 __PACKAGE__->method_documentation({
+     'data_source' => {
+     	datatype => 'DataSource',
+     	base_name => 'DataSource',
+     	description => 'Represents data source of task object.',
+     	format => '',
+     	read_only => '',
+     		},
      'workbook' => {
      	datatype => 'FileSource',
      	base_name => 'Workbook',
-     	description => '',
+     	description => 'Represents data source of task object.',
      	format => '',
      	read_only => '',
      		},
      'destination_file' => {
      	datatype => 'string',
      	base_name => 'DestinationFile',
-     	description => '',
+     	description => 'Represents destination file.',
+     	format => '',
+     	read_only => '',
+     		},
+     'region' => {
+     	datatype => 'string',
+     	base_name => 'Region',
+     	description => 'Represents Excel data region.',
      	format => '',
      	read_only => '',
      		},
      'save_options' => {
      	datatype => 'SaveOptions',
      	base_name => 'SaveOptions',
-     	description => '',
+     	description => 'Represents save options.',
      	format => '',
      	read_only => '',
      		},    
 });
 
 __PACKAGE__->swagger_types( {
+    'data_source' => 'DataSource',
     'workbook' => 'FileSource',
     'destination_file' => 'string',
+    'region' => 'string',
     'save_options' => 'SaveOptions' 
 } );
 
 __PACKAGE__->attribute_map( {
+    'data_source' => 'DataSource',
     'workbook' => 'Workbook',
     'destination_file' => 'DestinationFile',
+    'region' => 'Region',
     'save_options' => 'SaveOptions' 
 } );
 
