@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -128,21 +128,21 @@ __PACKAGE__->method_documentation({
      'formula1' => {
      	datatype => 'string',
      	base_name => 'Formula1',
-     	description => '',
+     	description => 'Gets and sets the value or expression associated with conditional formatting.',
      	format => '',
      	read_only => '',
      		},
      'formula2' => {
      	datatype => 'string',
      	base_name => 'Formula2',
-     	description => '',
+     	description => 'Gets and sets the value or expression associated with conditional formatting.',
      	format => '',
      	read_only => '',
      		},
      'operator' => {
      	datatype => 'string',
      	base_name => 'Operator',
-     	description => '',
+     	description => 'Gets and sets the conditional format operator type.',
      	format => '',
      	read_only => '',
      		},    
