@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => '           Represents the gradient fill.           ',
                                   class => 'GradientFill',
                                   required => [], # TODO
 }                                 );
@@ -128,28 +128,28 @@ __PACKAGE__->method_documentation({
      'fill_type' => {
      	datatype => 'string',
      	base_name => 'FillType',
-     	description => '',
+     	description => 'Gets the gradient fill type. ',
      	format => '',
      	read_only => '',
      		},
      'direction_type' => {
      	datatype => 'string',
      	base_name => 'DirectionType',
-     	description => '',
+     	description => 'Gets the gradient direction type. ',
      	format => '',
      	read_only => '',
      		},
      'angle' => {
      	datatype => 'double',
      	base_name => 'Angle',
-     	description => '',
+     	description => 'The angle of linear fill. ',
      	format => '',
      	read_only => '',
      		},
      'gradient_stops' => {
      	datatype => 'ARRAY[GradientFillStop]',
      	base_name => 'GradientStops',
-     	description => '',
+     	description => 'Represents the gradient stop collection. ',
      	format => '',
      	read_only => '',
      		},    
