@@ -35,6 +35,7 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
+use AsposeCellsCloud::Object::DataSource;
 use AsposeCellsCloud::Object::FileSource;
 use AsposeCellsCloud::Object::ImportOption;
 use AsposeCellsCloud::Object::TaskParameter; 
@@ -120,45 +121,63 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents import data task parameter.',
                                   class => 'ImportDataTaskParameter',
                                   required => [], # TODO
 }                                 );
 
 
 __PACKAGE__->method_documentation({
+     'data_source' => {
+     	datatype => 'DataSource',
+     	base_name => 'DataSource',
+     	description => 'Represents data source of task object.',
+     	format => '',
+     	read_only => '',
+     		},
      'workbook' => {
      	datatype => 'FileSource',
      	base_name => 'Workbook',
-     	description => '',
+     	description => 'Represents data source of task object.',
      	format => '',
      	read_only => '',
      		},
      'import_option' => {
      	datatype => 'ImportOption',
      	base_name => 'ImportOption',
-     	description => '',
+     	description => 'Represents import option.',
+     	format => '',
+     	read_only => '',
+     		},
+     'target_data_source' => {
+     	datatype => 'DataSource',
+     	base_name => 'TargetDataSource',
+     	description => 'Represents destination data source.',
      	format => '',
      	read_only => '',
      		},
      'destination_workbook' => {
      	datatype => 'FileSource',
      	base_name => 'DestinationWorkbook',
-     	description => '',
+     	description => 'Represents destination data source.',
      	format => '',
      	read_only => '',
      		},    
 });
 
 __PACKAGE__->swagger_types( {
+    'data_source' => 'DataSource',
     'workbook' => 'FileSource',
     'import_option' => 'ImportOption',
+    'target_data_source' => 'DataSource',
     'destination_workbook' => 'FileSource' 
 } );
 
 __PACKAGE__->attribute_map( {
+    'data_source' => 'DataSource',
     'workbook' => 'Workbook',
     'import_option' => 'ImportOption',
+    'target_data_source' => 'TargetDataSource',
     'destination_workbook' => 'DestinationWorkbook' 
 } );
 
