@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -119,7 +119,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => '           Encapsulates the object that represents pattern fill format           ',
                                   class => 'PatternFill',
                                   required => [], # TODO
 }                                 );
@@ -129,49 +129,49 @@ __PACKAGE__->method_documentation({
      'pattern' => {
      	datatype => 'string',
      	base_name => 'Pattern',
-     	description => '',
+     	description => 'Gets or sets the fill pattern type ',
      	format => '',
      	read_only => '',
      		},
      'background_cells_color' => {
      	datatype => 'CellsColor',
      	base_name => 'BackgroundCellsColor',
-     	description => '',
+     	description => 'Gets and sets the foreground  object. ',
      	format => '',
      	read_only => '',
      		},
      'foreground_cells_color' => {
      	datatype => 'CellsColor',
      	base_name => 'ForegroundCellsColor',
-     	description => '',
+     	description => 'Gets and sets the foreground  object. ',
      	format => '',
      	read_only => '',
      		},
      'foreground_color' => {
      	datatype => 'Color',
      	base_name => 'ForegroundColor',
-     	description => '',
+     	description => 'Gets or sets the foreground . ',
      	format => '',
      	read_only => '',
      		},
      'background_color' => {
      	datatype => 'Color',
      	base_name => 'BackgroundColor',
-     	description => '',
+     	description => 'Gets or sets the background  of the . ',
      	format => '',
      	read_only => '',
      		},
      'back_transparency' => {
      	datatype => 'double',
      	base_name => 'BackTransparency',
-     	description => '',
+     	description => 'Gets or sets the transparency of background color. ',
      	format => '',
      	read_only => '',
      		},
      'fore_transparency' => {
      	datatype => 'double',
      	base_name => 'ForeTransparency',
-     	description => '',
+     	description => 'Gets or sets the transparency of foreground color. ',
      	format => '',
      	read_only => '',
      		},    
