@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -121,7 +121,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Encapsulates the object that represents a single picture in a spreadsheet.',
                                   class => 'Picture',
                                   required => [], # TODO
 }                                 );
@@ -131,28 +131,28 @@ __PACKAGE__->method_documentation({
      'border_line_color' => {
      	datatype => 'Color',
      	base_name => 'BorderLineColor',
-     	description => '',
+     	description => 'Represents the  of the border line of a picture.',
      	format => '',
      	read_only => '',
      		},
      'border_weight' => {
      	datatype => 'double',
      	base_name => 'BorderWeight',
-     	description => '',
+     	description => 'Gets or sets the weight of the border line of a picture in units of pt.',
      	format => '',
      	read_only => '',
      		},
      'original_height' => {
      	datatype => 'int',
      	base_name => 'OriginalHeight',
-     	description => '',
+     	description => 'Gets the original height of the picture.',
      	format => '',
      	read_only => '',
      		},
      'original_width' => {
      	datatype => 'int',
      	base_name => 'OriginalWidth',
-     	description => '',
+     	description => 'Gets the original width of the picture.',
      	format => '',
      	read_only => '',
      		},
@@ -166,7 +166,7 @@ __PACKAGE__->method_documentation({
      'source_full_name' => {
      	datatype => 'string',
      	base_name => 'SourceFullName',
-     	description => '',
+     	description => 'Gets or sets the path and name of the source file for the linked image.',
      	format => '',
      	read_only => '',
      		},
