@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -121,7 +121,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents a radio button.',
                                   class => 'RadioButton',
                                   required => [], # TODO
 }                                 );
@@ -131,21 +131,21 @@ __PACKAGE__->method_documentation({
      'group_box' => {
      	datatype => 'GroupBox',
      	base_name => 'GroupBox',
-     	description => '',
+     	description => 'Gets the GroupBox that contains this RadioButton.',
      	format => '',
      	read_only => '',
      		},
      'is_checked' => {
      	datatype => 'boolean',
      	base_name => 'IsChecked',
-     	description => '',
+     	description => 'Indicates if the radiobutton is checked or not.',
      	format => '',
      	read_only => '',
      		},
      'shadow' => {
      	datatype => 'boolean',
      	base_name => 'Shadow',
-     	description => '',
+     	description => 'Indicates whether the combobox has 3-D shading.',
      	format => '',
      	read_only => '',
      		},
