@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -119,7 +119,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Indicates range copy request',
                                   class => 'RangeCopyRequest',
                                   required => [], # TODO
 }                                 );
@@ -129,28 +129,28 @@ __PACKAGE__->method_documentation({
      'operate' => {
      	datatype => 'string',
      	base_name => 'Operate',
-     	description => '',
+     	description => 'copydata, copystyle, copyto, copyvalue.',
      	format => '',
      	read_only => '',
      		},
      'source' => {
      	datatype => 'Range',
      	base_name => 'Source',
-     	description => '',
+     	description => 'Source range. ',
      	format => '',
      	read_only => '',
      		},
      'target' => {
      	datatype => 'Range',
      	base_name => 'Target',
-     	description => '',
+     	description => 'Target range.',
      	format => '',
      	read_only => '',
      		},
      'paste_options' => {
      	datatype => 'PasteOptions',
      	base_name => 'PasteOptions',
-     	description => '',
+     	description => 'Represents the paste special options.            ',
      	format => '',
      	read_only => '',
      		},    
