@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -35,6 +35,7 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
+use AsposeCellsCloud::Object::DataSource;
 use AsposeCellsCloud::Object::FileSource;
 use AsposeCellsCloud::Object::TaskParameter; 
 
@@ -119,7 +120,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents smart marker task parameter.',
                                   class => 'SmartMarkerTaskParameter',
                                   required => [], # TODO
 }                                 );
@@ -129,21 +130,42 @@ __PACKAGE__->method_documentation({
      'source_workbook' => {
      	datatype => 'FileSource',
      	base_name => 'SourceWorkbook',
-     	description => '',
+     	description => 'Represents data source of task object.',
      	format => '',
      	read_only => '',
      		},
      'destination_workbook' => {
      	datatype => 'FileSource',
      	base_name => 'DestinationWorkbook',
-     	description => '',
+     	description => 'Represents data source of task object.',
      	format => '',
      	read_only => '',
      		},
      'xml_file' => {
      	datatype => 'FileSource',
      	base_name => 'xmlFile',
-     	description => '',
+     	description => 'Represents xml file.',
+     	format => '',
+     	read_only => '',
+     		},
+     'data_source' => {
+     	datatype => 'DataSource',
+     	base_name => 'DataSource',
+     	description => 'Represents destination data source.',
+     	format => '',
+     	read_only => '',
+     		},
+     'target_data_source' => {
+     	datatype => 'DataSource',
+     	base_name => 'TargetDataSource',
+     	description => 'Represents destination data source.',
+     	format => '',
+     	read_only => '',
+     		},
+     'xml_file_data_source' => {
+     	datatype => 'DataSource',
+     	base_name => 'XMLFileDataSource',
+     	description => 'Represents xml file.',
      	format => '',
      	read_only => '',
      		},    
@@ -152,13 +174,19 @@ __PACKAGE__->method_documentation({
 __PACKAGE__->swagger_types( {
     'source_workbook' => 'FileSource',
     'destination_workbook' => 'FileSource',
-    'xml_file' => 'FileSource' 
+    'xml_file' => 'FileSource',
+    'data_source' => 'DataSource',
+    'target_data_source' => 'DataSource',
+    'xml_file_data_source' => 'DataSource' 
 } );
 
 __PACKAGE__->attribute_map( {
     'source_workbook' => 'SourceWorkbook',
     'destination_workbook' => 'DestinationWorkbook',
-    'xml_file' => 'xmlFile' 
+    'xml_file' => 'xmlFile',
+    'data_source' => 'DataSource',
+    'target_data_source' => 'TargetDataSource',
+    'xml_file_data_source' => 'XMLFileDataSource' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
