@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Indicates table total request',
                                   class => 'TableTotalRequest',
                                   required => [], # TODO
 }                                 );
@@ -128,21 +128,21 @@ __PACKAGE__->method_documentation({
      'list_column_index' => {
      	datatype => 'int',
      	base_name => 'ListColumnIndex',
-     	description => '',
+     	description => 'Indicates list column index.',
      	format => '',
      	read_only => '',
      		},
      'totals_calculation' => {
      	datatype => 'string',
      	base_name => 'TotalsCalculation',
-     	description => '',
+     	description => 'Indicates totals calculation.',
      	format => '',
      	read_only => '',
      		},
      'custom_formula' => {
      	datatype => 'string',
      	base_name => 'CustomFormula',
-     	description => '',
+     	description => 'Indicates custom formula.',
      	format => '',
      	read_only => '',
      		},    
