@@ -35,7 +35,7 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use AsposeCellsCloud::Object::FileSource; 
+use AsposeCellsCloud::Object::DataSource; 
 
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents task run result.',
                                   class => 'TaskRunResult',
                                   required => [], # TODO
 }                                 );
@@ -128,14 +128,14 @@ __PACKAGE__->method_documentation({
      'description' => {
      	datatype => 'string',
      	base_name => 'Description',
-     	description => '',
+     	description => 'Represents task run result description.',
      	format => '',
      	read_only => '',
      		},
      'out_file_list' => {
-     	datatype => 'ARRAY[FileSource]',
+     	datatype => 'ARRAY[DataSource]',
      	base_name => 'OutFileList',
-     	description => '',
+     	description => 'Represents out data file list.',
      	format => '',
      	read_only => '',
      		},    
@@ -143,7 +143,7 @@ __PACKAGE__->method_documentation({
 
 __PACKAGE__->swagger_types( {
     'description' => 'string',
-    'out_file_list' => 'ARRAY[FileSource]' 
+    'out_file_list' => 'ARRAY[DataSource]' 
 } );
 
 __PACKAGE__->attribute_map( {
