@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -121,7 +121,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Encapsulates the object that represents the walls of a 3-D chart.',
                                   class => 'Walls',
                                   required => [], # TODO
 }                                 );
@@ -131,35 +131,35 @@ __PACKAGE__->method_documentation({
      'center_x' => {
      	datatype => 'int',
      	base_name => 'CenterX',
-     	description => '',
+     	description => 'Gets the x coordinate of the left-bottom corner of Wall center in units of 1/4000 of chart`s width after calls Chart.Calculate() method.',
      	format => '',
      	read_only => '',
      		},
      'center_y' => {
      	datatype => 'int',
      	base_name => 'CenterY',
-     	description => '',
+     	description => 'Gets the y coordinate of the left-bottom corner of Wall center in units of 1/4000 of chart`s height after calls Chart.Calculate() method.',
      	format => '',
      	read_only => '',
      		},
      'depth' => {
      	datatype => 'int',
      	base_name => 'Depth',
-     	description => '',
+     	description => 'Gets the depth front to back in units of 1/4000 of chart`s width after calls Chart.Calculate() method.',
      	format => '',
      	read_only => '',
      		},
      'height' => {
      	datatype => 'int',
      	base_name => 'Height',
-     	description => '',
+     	description => 'Gets the height of top to bottom in units of 1/4000 of chart`s height after calls Chart.Calculate() method.',
      	format => '',
      	read_only => '',
      		},
      'width' => {
      	datatype => 'int',
      	base_name => 'Width',
-     	description => '',
+     	description => 'Gets the width of left to right in units of 1/4000 of chart`s width after calls Chart.Calculate() method.',
      	format => '',
      	read_only => '',
      		},
