@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,13 +59,13 @@ sub new {
 
 
 # Run Operation Request
-# DeleteWorksheetColumnsRequest.name : The workbook name.  ,
+# DeleteWorksheetColumnsRequest.name : The file name.  ,
 # DeleteWorksheetColumnsRequest.sheetName : The worksheet name.  ,
 # DeleteWorksheetColumnsRequest.columnIndex : The column index.  ,
 # DeleteWorksheetColumnsRequest.columns : The number of columns.  ,
 # DeleteWorksheetColumnsRequest.updateReference : Indicates if references in other worksheets will be updated.  ,
-# DeleteWorksheetColumnsRequest.folder : Original workbook folder.  ,
-# DeleteWorksheetColumnsRequest.storageName : Storage name.   
+# DeleteWorksheetColumnsRequest.folder : The folder where the file is situated.  ,
+# DeleteWorksheetColumnsRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -76,7 +76,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'delete_worksheet_columns' } = { 
-    	summary => 'Delete worksheet columns.',
+    	summary => 'Delete worksheet columns in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -147,7 +147,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -182,14 +182,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
