@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,11 +59,11 @@ sub new {
 
 
 # Run Operation Request
-# GetCellHtmlStringRequest.name :   ,
-# GetCellHtmlStringRequest.sheetName :   ,
-# GetCellHtmlStringRequest.cellName :   ,
-# GetCellHtmlStringRequest.folder :   ,
-# GetCellHtmlStringRequest.storageName :    
+# GetCellHtmlStringRequest.name : The file name.  ,
+# GetCellHtmlStringRequest.sheetName : The worksheet name.  ,
+# GetCellHtmlStringRequest.cellName : The cell name.  ,
+# GetCellHtmlStringRequest.folder : The folder where the file is situated.  ,
+# GetCellHtmlStringRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -74,7 +74,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'get_cell_html_string' } = { 
-    	summary => '',
+    	summary => 'Retrieve the HTML string containing data and specific formats in this cell.',
         params => $params,
         returns => 'string',
     };
@@ -137,35 +137,35 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'cell_name' => {
      	datatype => 'string',
      	base_name => 'cellName',
-     	description => '',
+     	description => 'The cell name.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
