@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,10 +59,10 @@ sub new {
 
 
 # Run Operation Request
-# GetWorksheetCommentsRequest.name : Workbook name.  ,
+# GetWorksheetCommentsRequest.name : The file name.  ,
 # GetWorksheetCommentsRequest.sheetName : The worksheet name.  ,
-# GetWorksheetCommentsRequest.folder : Original workbook folder.  ,
-# GetWorksheetCommentsRequest.storageName : Storage name.   
+# GetWorksheetCommentsRequest.folder : The folder where the file is situated.  ,
+# GetWorksheetCommentsRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -73,7 +73,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'get_worksheet_comments' } = { 
-    	summary => 'Get comments description in worksheet.',
+    	summary => 'Retrieve the description of comments in the worksheet.',
         params => $params,
         returns => 'CommentsResponse',
     };
@@ -130,7 +130,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'Workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -144,14 +144,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
