@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# GetWorksheetListObjectRequest.name :   ,
-# GetWorksheetListObjectRequest.sheetName :   ,
-# GetWorksheetListObjectRequest.listobjectindex :   ,
+# GetWorksheetListObjectRequest.name : The file name.  ,
+# GetWorksheetListObjectRequest.sheetName : The worksheet name.  ,
+# GetWorksheetListObjectRequest.listobjectindex : list object index.  ,
 # GetWorksheetListObjectRequest.format :   ,
-# GetWorksheetListObjectRequest.folder :   ,
-# GetWorksheetListObjectRequest.storageName :    
+# GetWorksheetListObjectRequest.folder : The folder where the file is situated.  ,
+# GetWorksheetListObjectRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -75,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'get_worksheet_list_object' } = { 
-    	summary => '',
+    	summary => 'Retrieve list object description by index in the worksheet.',
         params => $params,
         returns => 'string',
     };
@@ -142,21 +142,21 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'listobjectindex' => {
      	datatype => 'int',
      	base_name => 'listobjectindex',
-     	description => '',
+     	description => 'list object index.',
      	format => '',
      	read_only => '',
      		},
@@ -170,14 +170,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
