@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# GetWorksheetOleObjectRequest.name : The workbook name.  ,
+# GetWorksheetOleObjectRequest.name : The file name.  ,
 # GetWorksheetOleObjectRequest.sheetName : The worksheet name.  ,
 # GetWorksheetOleObjectRequest.objectNumber : The object number.  ,
 # GetWorksheetOleObjectRequest.format : Object conversion format(PNG/TIFF/JPEG/GIF/EMF/BMP).  ,
-# GetWorksheetOleObjectRequest.folder : Original workbook folder.  ,
-# GetWorksheetOleObjectRequest.storageName : Storage name.   
+# GetWorksheetOleObjectRequest.folder : The folder where the file is situated.  ,
+# GetWorksheetOleObjectRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -75,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'get_worksheet_ole_object' } = { 
-    	summary => 'Gets OLE object info or get the OLE object in some format.',
+    	summary => 'Retrieve the OLE object in a specified format in the worksheet.',
         params => $params,
         returns => 'string',
     };
@@ -142,7 +142,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -170,14 +170,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
