@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# PostAutofitWorkbookRowsRequest.name :   ,
-# PostAutofitWorkbookRowsRequest.startRow :   ,
-# PostAutofitWorkbookRowsRequest.endRow :   ,
-# PostAutofitWorkbookRowsRequest.onlyAuto :   ,
-# PostAutofitWorkbookRowsRequest.folder :   ,
-# PostAutofitWorkbookRowsRequest.storageName :    
+# PostAutofitWorkbookRowsRequest.name : The file name.  ,
+# PostAutofitWorkbookRowsRequest.startRow : Start row.  ,
+# PostAutofitWorkbookRowsRequest.endRow : End row.  ,
+# PostAutofitWorkbookRowsRequest.onlyAuto : Only auto.  ,
+# PostAutofitWorkbookRowsRequest.folder : The folder where the file is situated.  ,
+# PostAutofitWorkbookRowsRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -75,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_autofit_workbook_rows' } = { 
-    	summary => '',
+    	summary => 'Autofit rows in the workbook.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -138,42 +138,42 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'start_row' => {
      	datatype => 'int',
      	base_name => 'startRow',
-     	description => '',
+     	description => 'Start row.',
      	format => '',
      	read_only => '',
      		},
      'end_row' => {
      	datatype => 'int',
      	base_name => 'endRow',
-     	description => '',
+     	description => 'End row.',
      	format => '',
      	read_only => '',
      		},
      'only_auto' => {
      	datatype => 'string',
      	base_name => 'onlyAuto',
-     	description => '',
+     	description => 'Only auto.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
