@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,15 +59,15 @@ sub new {
 
 
 # Run Operation Request
-# PostCopyCellIntoCellRequest.name :   ,
-# PostCopyCellIntoCellRequest.destCellName :   ,
-# PostCopyCellIntoCellRequest.sheetName :   ,
-# PostCopyCellIntoCellRequest.worksheet :   ,
-# PostCopyCellIntoCellRequest.cellname :   ,
-# PostCopyCellIntoCellRequest.row :   ,
-# PostCopyCellIntoCellRequest.column :   ,
-# PostCopyCellIntoCellRequest.folder :   ,
-# PostCopyCellIntoCellRequest.storageName :    
+# PostCopyCellIntoCellRequest.name : The file name.  ,
+# PostCopyCellIntoCellRequest.destCellName : The destination cell name.  ,
+# PostCopyCellIntoCellRequest.sheetName : The destination worksheet name.  ,
+# PostCopyCellIntoCellRequest.worksheet : The source worksheet name.  ,
+# PostCopyCellIntoCellRequest.cellname : The source cell name.  ,
+# PostCopyCellIntoCellRequest.row : The source row index.  ,
+# PostCopyCellIntoCellRequest.column : The source column index.  ,
+# PostCopyCellIntoCellRequest.folder : The folder where the file is situated.  ,
+# PostCopyCellIntoCellRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -78,7 +78,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_copy_cell_into_cell' } = { 
-    	summary => '',
+    	summary => 'Copy data from a source cell to a destination cell in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -157,63 +157,63 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'dest_cell_name' => {
      	datatype => 'string',
      	base_name => 'destCellName',
-     	description => '',
+     	description => 'The destination cell name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The destination worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'worksheet' => {
      	datatype => 'string',
      	base_name => 'worksheet',
-     	description => '',
+     	description => 'The source worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'cellname' => {
      	datatype => 'string',
      	base_name => 'cellname',
-     	description => '',
+     	description => 'The source cell name.',
      	format => '',
      	read_only => '',
      		},
      'row' => {
      	datatype => 'int',
      	base_name => 'row',
-     	description => '',
+     	description => 'The source row index.',
      	format => '',
      	read_only => '',
      		},
      'column' => {
      	datatype => 'int',
      	base_name => 'column',
-     	description => '',
+     	description => 'The source column index.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
