@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,14 +59,14 @@ sub new {
 
 
 # Run Operation Request
-# PostCopyWorksheetColumnsRequest.name : The workbook name.  ,
+# PostCopyWorksheetColumnsRequest.name : The file name.  ,
 # PostCopyWorksheetColumnsRequest.sheetName : The worksheet name.  ,
 # PostCopyWorksheetColumnsRequest.sourceColumnIndex : Source column index  ,
 # PostCopyWorksheetColumnsRequest.destinationColumnIndex : Destination column index  ,
 # PostCopyWorksheetColumnsRequest.columnNumber : The copied column number  ,
 # PostCopyWorksheetColumnsRequest.worksheet : The destination worksheet name.  ,
-# PostCopyWorksheetColumnsRequest.folder : Original workbook folder.  ,
-# PostCopyWorksheetColumnsRequest.storageName : Storage name.   
+# PostCopyWorksheetColumnsRequest.folder : The folder where the file is situated.  ,
+# PostCopyWorksheetColumnsRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -77,7 +77,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_copy_worksheet_columns' } = { 
-    	summary => 'Copy data to destination columns from source columns in worksheet.',
+    	summary => 'Copy data from source columns to destination columns in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -150,7 +150,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -192,14 +192,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
