@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,13 +59,13 @@ sub new {
 
 
 # Run Operation Request
-# PostGroupWorksheetRowsRequest.name :   ,
-# PostGroupWorksheetRowsRequest.sheetName :   ,
-# PostGroupWorksheetRowsRequest.firstIndex :   ,
-# PostGroupWorksheetRowsRequest.lastIndex :   ,
-# PostGroupWorksheetRowsRequest.hide :   ,
-# PostGroupWorksheetRowsRequest.folder :   ,
-# PostGroupWorksheetRowsRequest.storageName :    
+# PostGroupWorksheetRowsRequest.name : The file name.  ,
+# PostGroupWorksheetRowsRequest.sheetName : The worksheet name.  ,
+# PostGroupWorksheetRowsRequest.firstIndex : The first row index to be operated.  ,
+# PostGroupWorksheetRowsRequest.lastIndex : The last row index to be operated.  ,
+# PostGroupWorksheetRowsRequest.hide : rows visible state  ,
+# PostGroupWorksheetRowsRequest.folder : The folder where the file is situated.  ,
+# PostGroupWorksheetRowsRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -76,7 +76,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_group_worksheet_rows' } = { 
-    	summary => '',
+    	summary => 'Group rows in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -145,49 +145,49 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'first_index' => {
      	datatype => 'int',
      	base_name => 'firstIndex',
-     	description => '',
+     	description => 'The first row index to be operated.',
      	format => '',
      	read_only => '',
      		},
      'last_index' => {
      	datatype => 'int',
      	base_name => 'lastIndex',
-     	description => '',
+     	description => 'The last row index to be operated.',
      	format => '',
      	read_only => '',
      		},
      'hide' => {
      	datatype => 'string',
      	base_name => 'hide',
-     	description => '',
+     	description => 'rows visible state',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
