@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,14 +59,14 @@ sub new {
 
 
 # Run Operation Request
-# PostPivotTableFieldMoveToRequest.name : The workbook name.  ,
+# PostPivotTableFieldMoveToRequest.name : The file name.  ,
 # PostPivotTableFieldMoveToRequest.sheetName : The worksheet name.  ,
-# PostPivotTableFieldMoveToRequest.pivotTableIndex : Gets the PivotTable report by index.  ,
-# PostPivotTableFieldMoveToRequest.fieldIndex : Gets the PivotField Object at the specific index.  ,
+# PostPivotTableFieldMoveToRequest.pivotTableIndex : The PivotTable index.  ,
+# PostPivotTableFieldMoveToRequest.fieldIndex : The pivot field index.  ,
 # PostPivotTableFieldMoveToRequest.from : The fields area type(Column/Row/Page/Data/Undefined).  ,
 # PostPivotTableFieldMoveToRequest.to : The fields area type(Column/Row/Page/Data/Undefined).  ,
-# PostPivotTableFieldMoveToRequest.folder : Original workbook folder.  ,
-# PostPivotTableFieldMoveToRequest.storageName : Storage name.   
+# PostPivotTableFieldMoveToRequest.folder : The folder where the file is situated.  ,
+# PostPivotTableFieldMoveToRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -77,7 +77,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_pivot_table_field_move_to' } = { 
-    	summary => 'Moves pivot field in pivot table.',
+    	summary => 'Move a pivot field in the PivotTable.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -152,7 +152,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -166,14 +166,14 @@ __PACKAGE__->method_documentation({
      'pivot_table_index' => {
      	datatype => 'int',
      	base_name => 'pivotTableIndex',
-     	description => 'Gets the PivotTable report by index.',
+     	description => 'The PivotTable index.',
      	format => '',
      	read_only => '',
      		},
      'field_index' => {
      	datatype => 'int',
      	base_name => 'fieldIndex',
-     	description => 'Gets the PivotField Object at the specific index.',
+     	description => 'The pivot field index.',
      	format => '',
      	read_only => '',
      		},
@@ -194,14 +194,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
