@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# PostRowStyleRequest.name :   ,
-# PostRowStyleRequest.sheetName :   ,
-# PostRowStyleRequest.rowIndex :   ,
-# PostRowStyleRequest.style :   ,
-# PostRowStyleRequest.folder :   ,
-# PostRowStyleRequest.storageName :    
+# PostRowStyleRequest.name : The file name.  ,
+# PostRowStyleRequest.sheetName : The worksheet name.  ,
+# PostRowStyleRequest.rowIndex : The row index.  ,
+# PostRowStyleRequest.style : Style description.  ,
+# PostRowStyleRequest.folder : The folder where the file is situated.  ,
+# PostRowStyleRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -75,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_row_style' } = { 
-    	summary => '',
+    	summary => 'Apply formats to an entire row in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -144,42 +144,42 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'row_index' => {
      	datatype => 'int',
      	base_name => 'rowIndex',
-     	description => '',
+     	description => 'The row index.',
      	format => '',
      	read_only => '',
      		},
      'style' => {
      	datatype => 'Style',
      	base_name => 'style',
-     	description => '',
+     	description => 'Style description.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
