@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,9 +59,9 @@ sub new {
 
 
 # Run Operation Request
-# PostWorksheetCellsRangeOutlineBorderRequest.name : The workbook name.  ,
+# PostWorksheetCellsRangeOutlineBorderRequest.name : The file name.  ,
 # PostWorksheetCellsRangeOutlineBorderRequest.sheetName : The worksheet name.  ,
-# PostWorksheetCellsRangeOutlineBorderRequest.rangeOperate : Range Set OutlineBorder Request   ,
+# PostWorksheetCellsRangeOutlineBorderRequest.rangeOperate : RangeSetOutlineBorderRequest Range Set OutlineBorder Request.  ,
 # PostWorksheetCellsRangeOutlineBorderRequest.folder : Original workbook folder.  ,
 # PostWorksheetCellsRangeOutlineBorderRequest.storageName : Storage name.   
 
@@ -74,7 +74,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_worksheet_cells_range_outline_border' } = { 
-    	summary => 'Sets outline border around a range of cells.',
+    	summary => 'Apply an outline border around a range of cells.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -137,7 +137,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -151,7 +151,7 @@ __PACKAGE__->method_documentation({
      'range_operate' => {
      	datatype => 'RangeSetOutlineBorderRequest',
      	base_name => 'rangeOperate',
-     	description => 'Range Set OutlineBorder Request ',
+     	description => 'RangeSetOutlineBorderRequest Range Set OutlineBorder Request.',
      	format => '',
      	read_only => '',
      		},
