@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -66,8 +66,8 @@ sub new {
 # PutVerticalPageBreakRequest.row : Row index, zero based.  ,
 # PutVerticalPageBreakRequest.startRow : Start row index, zero based.  ,
 # PutVerticalPageBreakRequest.endRow : End row index, zero based.  ,
-# PutVerticalPageBreakRequest.folder : Original workbook folder.  ,
-# PutVerticalPageBreakRequest.storageName : Storage name.   
+# PutVerticalPageBreakRequest.folder : The folder where the file is situated.  ,
+# PutVerticalPageBreakRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -78,7 +78,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'put_vertical_page_break' } = { 
-    	summary => 'Adds a vertical page break in worksheet.',
+    	summary => 'Add a vertical page break in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -204,14 +204,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
