@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# PutWorksheetChartTitleRequest.name :   ,
-# PutWorksheetChartTitleRequest.sheetName :   ,
-# PutWorksheetChartTitleRequest.chartIndex :   ,
-# PutWorksheetChartTitleRequest.title :   ,
-# PutWorksheetChartTitleRequest.folder :   ,
-# PutWorksheetChartTitleRequest.storageName :    
+# PutWorksheetChartTitleRequest.name : The file name.  ,
+# PutWorksheetChartTitleRequest.sheetName : The worksheet name.  ,
+# PutWorksheetChartTitleRequest.chartIndex : The chart index.  ,
+# PutWorksheetChartTitleRequest.title : TitleChart title.  ,
+# PutWorksheetChartTitleRequest.folder : The folder where the file is situated.  ,
+# PutWorksheetChartTitleRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -75,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'put_worksheet_chart_title' } = { 
-    	summary => '',
+    	summary => 'Set chart title in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -144,42 +144,42 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'chart_index' => {
      	datatype => 'int',
      	base_name => 'chartIndex',
-     	description => '',
+     	description => 'The chart index.',
      	format => '',
      	read_only => '',
      		},
      'title' => {
      	datatype => 'Title',
      	base_name => 'title',
-     	description => '',
+     	description => 'TitleChart title.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
